@@ -1,5 +1,5 @@
 /*
- * Copyright 2017 Walmart.
+ * Copyright 2020 Red Hat, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the 'License');
  * you may not use this file except in compliance with the License.
@@ -21,7 +21,7 @@
     .controller('PoolDetailsController', PoolDetailsController);
 
   PoolDetailsController.$inject = [
-    'horizon.dashboard.project.lbaasv2.patterns',
+    '$scope',
     'horizon.framework.util.i18n.gettext'
   ];
 
@@ -30,20 +30,27 @@
    * @name PoolDetailsController
    * @description
    * The `PoolDetailsController` controller provides functions for
-   * configuring the pool step of the LBaaS wizard.
-   * @param patterns The LBaaS v2 patterns constant.
+   * configuring the pool details step of the LBaaS wizard.
+   * @param $scope The angular scope object.
    * @param gettext The horizon gettext function for translation.
    * @returns undefined
    */
 
-  function PoolDetailsController(patterns, gettext) {
-
+  function PoolDetailsController($scope, gettext) {
     var ctrl = this;
+    ctrl.createChange = createChange;
 
-    ctrl.adminStateUpOptions = [
-      { label: gettext('Yes'), value: true },
-      { label: gettext('No'), value: false }
-    ];
+    function createChange() {
+      if ($scope.model.context.create_pool) {
+        // Enabling pool form enables listener form
+        $scope.model.context.create_listener = true;
+      } else {
+        // Disabling pool form disables monitor form
+        $scope.model.context.create_monitor = false;
+      }
+    }
 
+    // Error text for invalid fields
+    ctrl.tls_ciphersError = gettext('The cipher string must conform to OpenSSL syntax.');
   }
 })();
